==> keyclic_sdk_api-1.28.3.tar.gz: lib/model/result.dart <==
part of keyclic_sdk_api.api;

class Result {
  
  List<Activity> activities = [];
  

  int activityCount = null;
  

  int actorCount = null;
  

  DateTime createdAt = null;
  

  String group = null;
  

  String id = null;
  

  DateTime updatedAt = null;
  

  String verb = null;
  
  Result();

  @override
  String toString() {
    return 'Result[activities=$activities, activityCount=$activityCount, actorCount=$actorCount, createdAt=$createdAt, group=$group, id=$id, updatedAt=$updatedAt, verb=$verb, ]';
  }

  Result.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    activities =
      Activity.listFromJson(json['activities'])
;
    activityCount =
        json['activityCount']
    ;
    actorCount =
        json['actorCount']
    ;
    createdAt = json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    group =
        json['group']
    ;
    id =
        json['id']
    ;
    updatedAt = json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    verb =
        json['verb']
    ;
  }

  Map<String, dynamic> toJson() {
    return {
      'activities': activities,
      'activityCount': activityCount,
      'actorCount': actorCount,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'group': group,
      'id': id,
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
      'verb': verb
     };
  }

  static List<Result> listFromJson(List<dynamic> json) {
    return json == null ? new List<Result>() : json.map((value) => new Result.fromJson(value)).toList();
  }

  static Map<String, Result> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, Result>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new Result.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.28.6.tar.gz: lib/model/result.dart <==
part of keyclic_sdk_api.api;

class Result {
  List<Activity> activities = [];

  int activityCount = null;

  int actorCount = null;

  DateTime createdAt = null;

  String group = null;

  String id = null;

  DateTime updatedAt = null;

  String verb = null;

  Result();

  @override
  String toString() {
    return 'Result[activities=$activities, activityCount=$activityCount, actorCount=$actorCount, createdAt=$createdAt, group=$group, id=$id, updatedAt=$updatedAt, verb=$verb, ]';
  }

  Result.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    activities = Activity.listFromJson(json['activities']);
    activityCount = json['activityCount'];
    actorCount = json['actorCount'];
    createdAt =
        json['createdAt'] == null ? null : DateTime.parse(json['createdAt']);
    group = json['group'];
    id = json['id'];
    updatedAt =
        json['updatedAt'] == null ? null : DateTime.parse(json['updatedAt']);
    verb = json['verb'];
  }

  Map<String, dynamic> toJson() {
    return {
      'activities': activities,
      'activityCount': activityCount,
      'actorCount': actorCount,
      'createdAt': createdAt == null ? '' : createdAt.toUtc().toIso8601String(),
      'group': group,
      'id': id,
      'updatedAt': updatedAt == null ? '' : updatedAt.toUtc().toIso8601String(),
      'verb': verb
    };
  }

  static List<Result> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<Result>()
        : json.map((value) => new Result.fromJson(value)).toList();
  }

  static Map<String, Result> mapFromJson(
      Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, Result>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) =>
          map[key] = new Result.fromJson(value));
    }
    return map;
  }
}
